/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the MIPS RS-2030 keyboard.
 * By Cliff Marcellus (cliff@phys.ucalgary.ca)
 */

static const KeyCode rs2030_codes [] = {

  /* Row 0 */
  9,
  67, 68, 69, 70,
  71, 72, 73, 74,
  75, 76, 95, 96,
  92, 0, 78,

  /* Row 2 */
  49, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22,
  105, 107, 93,
  77, 106, 63, 82,

  /* Row 3 */
  23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 51,
  101, 108, 94,
  79, 80, 81, 86,
  
  /* Row 4 */
  66, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 36,
  83, 84, 85,

  /* Row 5 */
  50, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62,
  97,
  87, 88, 89, 102,

  /* Row 6 */
  37,
  64, 65, 104,
  103,
  98, 99, 100,
  90, 91
};
